==> gnuradio_3.6.5.1.orig.tar.gz: gnuradio-3.6.5.1/gr-blocks/lib/tagged_stream_to_pdu_impl.h <==
/* -*- c++ -*- */
/*
 * Copyright 2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_TAGGED_STREAM_TO_PDU_IMPL_H
#define INCLUDED_TAGGED_STREAM_TO_PDU_IMPL_H

#include <blocks/tagged_stream_to_pdu.h>

namespace gr {
  namespace blocks {

    class BLOCKS_API tagged_stream_to_pdu_impl : public tagged_stream_to_pdu
    {
      size_t               d_itemsize;
      size_t               d_pdu_length;
      size_t               d_pdu_remain;
      bool                 d_inpdu;
      pdu::vector_type     d_type;
      std::vector<uint8_t> d_save;
      pmt::pmt_t           d_pdu_meta;
      pmt::pmt_t           d_pdu_vector;

      std::vector<gr_tag_t>::iterator d_tags_itr;
      std::vector<gr_tag_t> d_tags;
      
    public:
      tagged_stream_to_pdu_impl(pdu::vector_type type);

      int work(int noutput_items,
	       gr_vector_const_void_star &input_items,
	       gr_vector_void_star &output_items);

      void send_message();
    };

  } /* namespace blocks */
} /* namespace gr */

#endif

==> gnuradio_3.7.2.1.orig.tar.gz: gnuradio-3.7.2.1/gr-blocks/lib/tagged_stream_to_pdu_impl.h <==
/* -*- c++ -*- */
/*
 * Copyright 2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_TAGGED_STREAM_TO_PDU_IMPL_H
#define INCLUDED_TAGGED_STREAM_TO_PDU_IMPL_H

#include <gnuradio/blocks/tagged_stream_to_pdu.h>

namespace gr {
  namespace blocks {

    class BLOCKS_API tagged_stream_to_pdu_impl : public tagged_stream_to_pdu
    {
      size_t               d_itemsize;
      size_t               d_pdu_length;
      size_t               d_pdu_remain;
      bool                 d_inpdu;
      pdu::vector_type     d_type;
      std::vector<uint8_t> d_save;
      pmt::pmt_t           d_pdu_meta;
      pmt::pmt_t           d_pdu_vector;

      pmt::pmt_t           d_tag;
      std::vector<tag_t>::iterator d_tags_itr;
      std::vector<tag_t> d_tags;
      
    public:
      tagged_stream_to_pdu_impl(pdu::vector_type type, const std::string& lengthtagname);

      int work(int noutput_items,
	       gr_vector_const_void_star &input_items,
	       gr_vector_void_star &output_items);

      void send_message();
    };

  } /* namespace blocks */
} /* namespace gr */

#endif
